@@ -13,6 +13,6 @@
 # limitations under the License.
 
 from __future__ import unicode_literals, absolute_import
-from .testagent import TestAgent  # noqa
+from .agent import *  # noqa
 
-__version__ = '7.5.0'
+__version__ = '8.0'
