@@ -95,14 +95,14 @@ class ElementWrapper(object):
     r"""
     Wrapper for an ``lxml.etree`` element, providing additional methods useful
     for driving/testing WSGI applications. ``ElementWrapper`` objects are
-    normally created through the ``find``/``css`` methods of ``TestAgent``
+    normally created through the ``find``/``css`` methods of ``Agent``
     instance::
 
         >>> from fresco import Response
-        >>> from flea import TestAgent
+        >>> from flea import Agent
         >>> myapp = Response(['<html><body><a href="/">link 1</a>'\
         ...                   '<a href="/">link 2</a></body></html>'])
-        >>> agent = TestAgent(myapp).get('/')
+        >>> agent = Agent(myapp).get('/')
         >>> elementwrapper = agent.find('//a')[0]
 
     ``ElementWrapper`` objects have many methods and properties implemented as
@@ -199,7 +199,7 @@ class ElementWrapper(object):
     @when("a[@href]")  # NOQA
     def click(self, follow=True, check_status=True):
         """
-        Follow a link and return a new instance of ``TestAgent``
+        Follow a link and return a new instance of ``Agent``
         """
         return self.agent._click(self, follow=follow,
                                  check_status=check_status)
@@ -426,7 +426,7 @@ class ElementWrapper(object):
     @when("input[@type='submit' or @type='image']|button[@type='submit' or not(@type)]")  # NOQA
     def submit(self, follow=True, check_status=True):
         """
-        Submit the form, returning a new ``TestAgent`` object, by clicking on
+        Submit the form, returning a new ``Agent`` object, by clicking on
         the selected submit element (input of
         type submit or image, or button with type submit)
         """
@@ -435,7 +435,7 @@ class ElementWrapper(object):
     @when("form")  # NOQA
     def submit(self, button=None, follow=True, check_status=True):
         """
-        Submit the form, returning a new ``TestAgent`` object
+        Submit the form, returning a new ``Agent`` object
         """
         method = self.el.attrib.get('method', 'GET').upper()
         data = self.submit_data(button)
@@ -724,10 +724,10 @@ class ElementWrapper(object):
         Example::
 
             >>> from fresco import Response
-            >>> from flea import TestAgent
+            >>> from flea import Agent
             >>> myapp = Response(['<p>the <span>foo</span> is'\
             ...                   ' completely <strong>b</strong>azzed</p>'])
-            >>> agent = TestAgent(myapp).get('/')
+            >>> agent = Agent(myapp).get('/')
             >>> agent['//p'].striptags()
             'the foo is completely bazzed'
 
@@ -753,11 +753,11 @@ class ResultWrapper(list):
 
     ``ResultWrapper`` objects usually wrap ``ElementWrapper`` objects, which in
     turn wrap an lxml element and are normally created through the find/findcss
-    methods of ``TestAgent``::
+    methods of ``Agent``::
 
         >>> from fresco import Response
         >>> myapp = Response(['<html><p>item 1</p><p>item 2</p></html>'])
-        >>> agent = TestAgent(myapp).get('/')
+        >>> agent = Agent(myapp).get('/')
         >>> resultwrapper = agent.find('//p')
 
     ``ResultWrapper`` objects have list like behaviour::
